From 41eeb2bb8c0ba2a5af9401795711a2c467dc6209 Mon Sep 17 00:00:00 2001
From: Michael Goderbauer
Date: Thu, 29 Feb 2024 11:08:25 -0800
Subject: [PATCH] Use dartpad's main channel for master/main docs (#144329)
Dartpad doesn't have a "master" channel anymore, it got renamed to "main". Sadly, specifying "master" is now falling back to "stable" which breaks some of our examples in the docs that require a more current Flutter version, e.g. https://main-api.flutter.dev/flutter/material/TextButton-class.html
---
dev/bots/docs.sh | 2 +-
dev/snippets/config/skeletons/dartpad-sample.html | 2 +-
dev/tools/create_api_docs.dart | 5 ++---
dev/tools/test/create_api_docs_test.dart | 2 +-
4 files changed, 5 insertions(+), 6 deletions(-)
diff --git a/dev/bots/docs.sh b/dev/bots/docs.sh
index d6837fd361..08374e7e4c 100755
--- a/dev/bots/docs.sh
+++ b/dev/bots/docs.sh
@@ -116,7 +116,7 @@ function generate_docs() {
# Install and activate the snippets tool, which resides in the
# assets-for-api-docs repo:
# https://github.com/flutter/assets-for-api-docs/tree/master/packages/snippets
- "$DART" pub global activate snippets 0.4.0
+ "$DART" pub global activate snippets 0.4.2
# This script generates a unified doc set, and creates
# a custom index.html, placing everything into DOC_DIR.
diff --git a/dev/snippets/config/skeletons/dartpad-sample.html b/dev/snippets/config/skeletons/dartpad-sample.html
index 9afc6233d9..d8ce7cafd3 100644
--- a/dev/snippets/config/skeletons/dartpad-sample.html
+++ b/dev/snippets/config/skeletons/dartpad-sample.html
@@ -13,7 +13,7 @@
{@end-inject-html}
\ No newline at end of file
diff --git a/dev/tools/test/create_api_docs_test.dart b/dev/tools/test/create_api_docs_test.dart
index 8e6d8e6f73..560eaef590 100644
--- a/dev/tools/test/create_api_docs_test.dart
+++ b/dev/tools/test/create_api_docs_test.dart
@@ -441,7 +441,7 @@ void main() {
''');
- const String queryParams = 'split=1&run=true&sample_id=widgets.Listener.123&sample_channel=master&channel=master';
+ const String queryParams = 'split=1&run=true&sample_id=widgets.Listener.123&channel=main';
widgetsDir.childFile('Listener-class.html').writeAsStringSync('''
diff --git a/dev/tools/create_api_docs.dart b/dev/tools/create_api_docs.dart
index 12c49deb7d..150204cc1a 100644
--- a/dev/tools/create_api_docs.dart
+++ b/dev/tools/create_api_docs.dart
@@ -742,14 +742,13 @@ class DartdocGenerator {
// Check a "dartpad" example, any one will do, and check for the correct URL
// arguments.
// Just use "master" for any branch other than the LUCI_BRANCH.
final String? luciBranch = platform.environment['LUCI_BRANCH']?.trim();
- final String expectedBranch = luciBranch != null && luciBranch.isNotEmpty ? luciBranch : 'master';
+ final String expectedBranch = luciBranch != null && luciBranch.isNotEmpty ? luciBranch : 'main';
final List argumentRegExps = [
r'split=\d+',
r'run=true',
r'sample_id=widgets\.Listener\.\d+',
- 'sample_channel=$expectedBranch',
'channel=$expectedBranch',
];
for (final String argumentRegExp in argumentRegExps) {
@@ -742,14 +742,13 @@ class DartdocGenerator {
// Check a "dartpad" example, any one will do, and check for the correct URL
// arguments.
- // Just use "master" for any branch other than the LUCI_BRANCH.
+ // Just use "main" for any branch other than the LUCI_BRANCH.
final String? luciBranch = platform.environment['LUCI_BRANCH']?.trim();